@@ -60,7 +60,12 @@ class Decompressor():
         
         upload_start = time.time()
         logging.info(f"start uploading files for: {local_file}")
-        await self.upload_decompressed_files(container_name, dest_dir, decompression_dir)
+
+        properties = await blob_client.get_blob_properties()
+        metadata = properties.metadata
+        metadata_json = json.dumps(metadata)
+
+        await self.upload_decompressed_files(container_name, dest_dir, decompression_dir, metadata_json)
         upload_end = time.time()
         logging.info(f"end uploading files for: {local_file}, takes {upload_end - upload_start}")
 
@@ -78,16 +83,16 @@ class Decompressor():
 
         return files
 
-    async def upload_decompressed_files(self, container_name, dest_dir, decompression_dir):
+    async def upload_decompressed_files(self, container_name, dest_dir, decompression_dir, metadata_json):
         blob_service_client = BlobServiceClient.from_connection_string(self.conn_str)
 
         files_to_upload = self.get_files_to_upload(decompression_dir)
 
         async with blob_service_client:
             for file in files_to_upload:
-                await self.upload_decompressed_file(blob_service_client, file, container_name, dest_dir)      
+                await self.upload_decompressed_file(blob_service_client, file, container_name, dest_dir, metadata_json)      
 
-    async def upload_decompressed_file(self, blob_service_client, file, container_name, dest_dir):
+    async def upload_decompressed_file(self, blob_service_client, file, container_name, dest_dir, metadata_json):
         blob_name = os.path.basename(file)
         
         blob_client = blob_service_client.get_blob_client(container=container_name, blob="{}/{}".format(dest_dir, blob_name))
@@ -95,10 +100,6 @@ class Decompressor():
         async with async_open(file, "rb") as afp:
             await blob_client.upload_blob(await afp.read(), overwrite=True)     
 
-        properties = await blob_client.get_blob_properties()
-        metadata = properties.metadata
-        metadata_json = json.dumps(metadata)
-
         producer = EventHubProducerClient.from_connection_string(
             conn_str=self.eventhub_conn_str,
             eventhub_name=self.eventhub_name,
